@@ -3,17 +3,37 @@ from __future__ import annotations
 import json
 import logging
 import os
+import posixpath
 import re
 import shlex
 import tempfile
-from typing import Literal, TypedDict, Union, cast
+from platform import system
+from typing import Literal, Optional, TypedDict, Union, cast
 
 from ffmpeg_progress_yield import FfmpegProgress
 from tqdm import tqdm
 
+IS_WIN = system() in ["Windows", "cli"]
+
 logger = logging.getLogger("scenecut-extractor")
 
 
+def win_path_check(path: str) -> str:
+    """
+    Format a file path correctly for Windows
+
+    Args:
+        path (str): The path to format
+
+    Returns:
+        str: The formatted path
+    """
+    if IS_WIN:
+        # inside filters, we need to escape the colon twice
+        return path.replace("\\", "/").replace(":", "\\\\:")
+    return path
+
+
 class ScenecutInfo(TypedDict):
     frame: int
     """The frame number"""
@@ -35,7 +55,7 @@ class ScenecutExtractor:
         Args:
             input_file (str): the input file
         """
-        self.scenecuts: list[ScenecutInfo] = []
+        self.scenecuts: Optional[list[ScenecutInfo]] = None
         self.input_file = input_file
 
     def get_as_csv(self) -> str:
@@ -48,7 +68,7 @@ class ScenecutExtractor:
         Raises:
             RuntimeError: if no scene cuts have been calculated yet
         """
-        if len(self.scenecuts) == 0:
+        if self.scenecuts is None:
             raise RuntimeError("No scene cuts calculated yet")
 
         ret = ",".join(self.scenecuts[0].keys()) + "\n"
@@ -68,7 +88,7 @@ class ScenecutExtractor:
         Raises:
             RuntimeError: if no scene cuts have been calculated yet
         """
-        if len(self.scenecuts) == 0:
+        if self.scenecuts is None:
             raise RuntimeError("No scene cuts calculated yet")
 
         return json.dumps(self.scenecuts, indent=2)
@@ -79,7 +99,13 @@ class ScenecutExtractor:
 
         Returns:
             list[ScenecutInfo]: the scene cuts
+
+        Raises:
+            RuntimeError: if no scene cuts have been calculated yet
         """
+        if self.scenecuts is None:
+            raise RuntimeError("No scene cuts calculated yet")
+
         return self.scenecuts
 
     def calculate_scenecuts(
@@ -96,7 +122,7 @@ class ScenecutExtractor:
             raise RuntimeError("Threshold must be between 0 and 1")
 
         temp_dir = tempfile.mkdtemp()
-        temp_file_name = os.path.join(
+        temp_file_name = posixpath.join(
             temp_dir, "scenecut-extractor-" + os.path.basename(self.input_file) + ".txt"
         )
 
@@ -112,7 +138,8 @@ class ScenecutExtractor:
                 "-i",
                 self.input_file,
                 "-vf",
-                "select=gte(scene\,0),metadata=print:file=" + temp_file_name,
+                "select=gte(scene\,0),metadata=print:file="
+                + win_path_check(temp_file_name),
                 "-an",
                 "-f",
                 "null",
@@ -185,7 +212,7 @@ class ScenecutExtractor:
             no_copy (bool, optional): Do not copy the streams, reencode them. Defaults to False.
             progress (bool, optional): Show progress bar. Defaults to False.
         """
-        if len(self.scenecuts) == 0:
+        if self.scenecuts is None:
             raise RuntimeError("No scene cuts calculated yet")
 
         # insert one at the beginning
